@@ -111,10 +111,7 @@ def make_exe(fn):
         logger.info('Changed mode of %s to %s', fn, oct(newmode))
 
 def install_setuptools(py_executable):
-    if sys.version_info[:2] == (2, 4):
-        setup_fn = 'setuptools-0.6c7-py2.4.egg'
-    elif sys.version_info[:2] == (2, 5):
-        setup_fn = 'setuptools-0.6c7-py2.5.egg'
+    setup_fn = 'setuptools-0.6c7-py%s.egg' % sys.version[:3]
     setup_fn = join(os.path.dirname(__file__), 'support-files', setup_fn)
     cmd = [py_executable, '-c', EZ_SETUP_PY]
     if os.path.exists(setup_fn):
